@@ -1,15 +1,15 @@
 #' @import yaml
 #' @export 
 print.fs_object <- function(x, ...){
-  cat(as.yaml(x))
-# x
+#  cat(as.yaml(x))
+x
 }
 
 #' @import yaml
 #' @export 
 summary.fs_object <- function(object, ...){
-  cat(as.yaml(object))
-# object
+#  cat(as.yaml(object))
+  object
 }
 
 
